@@ -65,14 +65,6 @@ module TMail
     'z'   =>   0 * 60
   }
 
-  tspecial     = Regexp.quote( '()<>@,.;:\\"/[]?=' )
-  TSPECIAL     = /[#{tspecial}]/
-  control      = '\x00-\x1f\x7f-\xff'
-  CONTROL      = /[#{control}]/
-  INSECURE     = /[#{tspecial}#{control} ]/
-  INSECURE_PH  = /[#{tspecial}#{control}]/
-
-  ENCODED = /=\?[^\s?=]+\?[qb]\?[^\s?=]+\?=/i
 
   class << self
 
@@ -104,26 +96,6 @@ module TMail
       ret
     end
 
-    def quote( str )
-      if INSECURE === str then
-        '"' + str.gsub('"', '\\\\"') << '"'
-      else
-        str
-      end
-    end
-
-    def quote_phrase( str )
-      if INSECURE_PH === str then
-        '"' + str.gsub('"', '\\\\"') << '"'
-      else
-        str
-      end
-    end
-
-    def encoded?( str )
-      ENCODED === str
-    end
-
 
     # internal use
 
@@ -615,7 +587,7 @@ module TMail
 
 
 
-  class AddressGroup < DelegateClass( Array )
+  class AddressGroup < DelegateClass(Array)
 
     def initialize( name, arg = nil )
       @name = name
@@ -624,14 +596,14 @@ module TMail
 
     attr :name, true
     
-    def eql?( oth )
-      super( oth ) and self.name == oth.name
+    def eql?( other )
+      super other and self.name == other.name
     end
 
     alias == eql?
 
     def each_address
-      bare_each do |mbox|
+      each do |mbox|
         if AddressGroup === mbox then
           mbox.each {|i| yield i }
         else
@@ -645,7 +617,7 @@ module TMail
       stra.meta ':'
       stra.space
       first = true
-      bare_each do |mbox|
+      each do |mbox|
         if first then
           first = false
         else
@@ -1025,9 +997,7 @@ module TMail
       @params.each do |k,v|
         stra.meta ';'
         stra.space
-        stra.meta k
-        stra.meta '='
-        stra.value v
+        stra.kv_pair k, v
       end
     end
 
@@ -1088,9 +1058,7 @@ module TMail
       @params.each do |k,v|
         stra.meta ';'
         stra.space
-        stra.meta k
-        stra.meta '='
-        stra.value v
+        stra.kv_pair k, v
       end
     end
       
