@@ -63,11 +63,12 @@ module TMail
 
     class << self
 
-      def load_from( fname )
+      def load( fname )
         new FilePort.new( fname )
       end
 
-      alias loadfrom load_from
+      alias load_from load
+      alias loadfrom load
 
       def parse( str )
         new StringPort.new( str )
@@ -579,17 +580,22 @@ module TMail
       @header['date'].date = t
     end
 
+    def strftime( fmt )
+      if t = date then
+        t.strftime(fmt)
+      else
+        nil
+      end
+    end
+
+
     tmail_attr :to_addrs, 'to', 'addrs'
     tmail_attr :cc_addrs, 'cc', 'addrs'
     tmail_attr :bcc_addrs, 'bcc', 'addrs'
 
-    def to( dflt = '' )
-      arr = to_addrs
-      if arr and arr[0] then
-        arr[0]
-      else
-        dflt
-      end
+    def to( default = nil )
+      addr, = to_addrs(nil)
+      addr || default
     end
 
     def to=( addr )
@@ -604,17 +610,13 @@ module TMail
 
     tmail_attr :from_addrs, 'from', 'addrs'
 
-    def from_addrs=( arr )
-      store 'From', ''
-      @header['from'].addrs.replace arr
+    def from_addrs=( *arr )
+      store 'From', arr.flatten.join(', ')
     end
 
     def from_addr( default = nil )
-      if arr = from_addrs(nil) then
-        arr[0] || default
-      else
-        default
-      end
+      addr, = from_addrs(nil)
+      addr || default
     end
 
     def from_address( default = nil )
@@ -625,13 +627,7 @@ module TMail
       end
     end
 
-    alias from from_address
-
-    def from_address=( addr )
-      store 'From', addr
-    end
-
-    alias from= from_address=
+    alias from_address= from_addrs=
 
     def from_phrase( default = nil )
       if a = from_addr(nil) then
@@ -641,6 +637,16 @@ module TMail
       end
     end
 
+    def from( default = nil )
+      if a = from_addr then
+        a.phrase || a.address
+      else
+        default
+      end
+    end
+
+    alias from= from_addrs=
+
 
     tmail_attr :reply_to_addrs, 'reply-to', 'addrs'
 
@@ -655,22 +661,25 @@ module TMail
     tmail_attr :subject, 'subject', 'body'
 
     def subject=( str )
-      unless str then
-        delete 'subject'
-      else
+      if str then
         store 'Subject', str
+      else
+        @header.delete 'subject'
       end
       str
     end
 
 
-    tmail_attr :msgid, 'message-id', 'msgid'
+    tmail_attr :message_id, 'message-id', 'msgid'
 
-    def msgid=( str )
+    def message_id=( str )
       store 'Message-ID', str
       str
     end
 
+    alias msgid  message_id
+    alias msgid= message_id=
+
 
     tmail_attr :references, 'references', 'msgids'
 
@@ -791,8 +800,8 @@ module TMail
     alias each_dest each_destination
 
 
-    def reply_addresses
-      reply_to_addrs(nil) or from_addrs(nil)
+    def reply_addresses( default = nil )
+      reply_to_addrs(nil) or from_addrs(nil) or default
     end
 
     def error_reply_addresses
